<?php

namespace Bydedi\Shipping\Ups\Service\Locator\Json;

use Bydedi\Shipping\Ups\Service\Exception\Exception;
use Bydedi\Shipping\Ups\Service\Exception\NetworkErrorException;
use Bydedi\Shipping\Ups\Service\Exception\ResponseSyntaxErrorException;
use Bydedi\Shipping\Ups\Service\Exception\SyntaxErrorException;
use Bydedi\Shipping\Ups\Service\Exception\UnknownOperationException;
use Bydedi\Shipping\Ups\Service\Exception\UnrecognizedErrorException;
use Bydedi\Shipping\Ups\Service\Locator\Params\UpsParam;
use GuzzleHttp\ClientInterface;
use stdClass;

/**
 * Class Client
 */
class Client
{

    /**
     * @var string
     */
    protected $env;

    /**
     * @var ClientInterface
     */
    protected $guzzle;


    /**
     * Client constructor.
     *
     * @param $env
     */
    public function __construct($env, ClientInterface $client)
    {
        $this->env    = $env;
        $this->guzzle = $client;
    }

    /**
     * @return string
     */
    protected function getEndpoint()
    {
        return $this->env === 'prod'
            ? 'https://onlinetools.ups.com/rest/Locator'
            : 'https://wwwcie.ups.com/rest/Locator'
        ;
    }


    /**
     * @return ClientInterface
     */
    protected function getGuzzle()
    {
        return $this->guzzle;
    }


    /**
     * @param  UpsParam $upsParam
     * @return stdClass
     *
     * @throws ResponseSyntaxErrorException
     * @throws Exception
     * @throws NetworkErrorException
     * @throws SyntaxErrorException
     * @throws UnknownOperationException
     * @throws UnrecognizedErrorException
     */
    public function doRequest(UpsParam $upsParam)
    {
        $upsParam    = $upsParam->jsonSerialize();
        $response    = $this->getGuzzle()->request('post', $this->getEndpoint(), ['json' => $upsParam]);
        $contents    = $response->getBody()->getContents();
        $objResponse = json_decode($contents);
        if (empty($objResponse)) {
            throw new ResponseSyntaxErrorException($contents);
        }

        $statusDescription = $objResponse->LocatorResponse->Response->ResponseStatusDescription;
        $responseStatusCode        = $objResponse->LocatorResponse->Response->ResponseStatusCode;
        if ($statusDescription != 'Success') {
            $error        = $objResponse->LocatorResponse->Response->Error;
            $errorMessage = "$responseStatusCode : {$error->ErrorDescription}";
            switch ($responseStatusCode) {
                case 1:
                    throw new UnrecognizedErrorException($error, $errorMessage);

                    break;
                case 2:
                    throw new UnknownOperationException($error, $errorMessage);

                    break;
                case 3:
                    throw new NetworkErrorException($error, $errorMessage);

                    break;
                case 4:
                    throw new SyntaxErrorException($error, $errorMessage);

                    break;
                default:
                    throw new Exception($error, "$errorMessage Code : $responseStatusCode");
            }
        }

        return $objResponse;
    }
}
