<?php

namespace Bydedi\Shipping\Ups\Service\Locator\Json;

use Bydedi\Shipping\Relay;
use stdClass;

/**
 * Class RelayFormatter
 *
 * @package Bydedi\Shipping\Ups\Service\Locator\Json
 */
class RelayFormatter
{
    /**
     * @param  stdClass $jsonResponse
     * @return Relay[]
     */
    public function makeRelays($jsonResponse)
    {
        $dropLocations = $jsonResponse->LocatorResponse->SearchResults->DropLocation;
        if (is_array($dropLocations)) {
            return array_map(
                function ($dropLocation) {
                    return $this->makeRelay($dropLocation);
                },
                $dropLocations
            );
        }

        return [$this->makeRelay($dropLocations)];
    }


    /**
     * @param
     * @return Relay
     */
    public function makeRelay($dropLocation)
    {
        $schedule = $this->getSchedule($dropLocation);

        $relay = new Relay(
            $dropLocation->AccessPointInformation->PublicAccessPointID,
            $dropLocation->AddressKeyFormat->ConsigneeName,
            $dropLocation->AddressKeyFormat->AddressLine,
            '',
            $dropLocation->AddressKeyFormat->PostcodePrimaryLow,
            $dropLocation->AddressKeyFormat->PoliticalDivision2,
            $dropLocation->AddressKeyFormat->CountryCode,
            $dropLocation->Geocode->Latitude,
            $dropLocation->Geocode->Longitude,
            $schedule,
            $dropLocation->Distance->Value
        );

        return $relay;
    }

    /**
     * @param  $dropLocation
     * @return array
     */
    protected function getSchedule($dropLocation)
    {
        $days = [1 => 'Dimanche', // USA...
            2 => 'Lundi', 3 => 'Mardi', 4 => 'Mercredi', 5 => 'Jeudi', 6 => 'Vendredi', 7 => 'Samedi',];
        return array_reduce(
            $dropLocation->OperatingHours->StandardHours->DayOfWeek,
            function ($schedule, $day) use ($days) {
                $dayName = $days[(int)$day->Day];
                if (empty($day->OpenHours)) {
                    $schedule[$dayName] = [];
                    return $schedule;
                }
                $schedule[$dayName] = [$day->OpenHours, $day->CloseHours];
                $schedule[$dayName] = array_map(
                    function ($hour) {
                        $hour = str_pad($hour, 4, "0", STR_PAD_LEFT);
                        $hour = substr_replace($hour, ':', 2, 0);
                        return $hour;
                    },
                    $schedule[$dayName]
                );
                return $schedule;
            },
            []
        );
    }
}
