<?php

namespace Bydedi\Shipping\Ups\Service\Locator;

use Bydedi\Shipping\Relay;
use Bydedi\Shipping\Ups\Service\Exception\Exception;
use Bydedi\Shipping\Ups\Service\Exception\ResponseSyntaxErrorException;

/**
 * Class Locator
 */
class Locator
{

    /**
     * @var RelayFetcherInterface
     */
    protected $fetcher;

    /**
     * @var RequestFormatter
     */
    protected $requestFormatter;


    /**
     * Locator constructor.
     *
     * @param RequestFormatter      $requestFormatter
     * @param RelayFetcherInterface $fetcher
     */
    public function __construct(RequestFormatter $requestFormatter, RelayFetcherInterface $fetcher)
    {
        $this->fetcher               = $fetcher;
        $this->requestFormatter = $requestFormatter;
    }


    /**
     * @param  $addressLine
     * @param  $city
     * @param  $zipCode
     * @param  $coutnryIsoCode2
     * @param  $phoneNumber
     * @param  $locale
     * @return Relay[]
     *
     * @throws Exception
     * @throws ResponseSyntaxErrorException
     */
    public function getRelays(
        $addressLine = '',
        $city = '',
        $zipCode = '',
        $coutnryIsoCode2 = '',
        $phoneNumber = '',
        $locale = 'fr_FR'
    ) {
        $param  = $this->requestFormatter->getRequest(
            $addressLine,
            $city,
            $zipCode,
            $coutnryIsoCode2,
            $phoneNumber,
            '',
            $locale
        );
        $access = $this->requestFormatter->getAccessRequest();
        return $this->fetcher->fetchRelays($param, $access);
    }


    /**
     * @param  $locationId
     * @param  string     $city
     * @param  string     $coutnryIsoCode2
     * @param  string     $locale
     * @return Relay
     */
    public function getRelay($locationId, $city = '', $coutnryIsoCode2 = '', $locale = 'fr_FR')
    {
        $param  = $this->requestFormatter->getRequest('', $city, '', $coutnryIsoCode2, '', $locationId, $locale);
        $relays = $this->fetcher->fetchRelays($param, $this->requestFormatter->getAccessRequest());
        $count  = count($relays);
        if ($count != 1) {
            trigger_error("Invalid relay result : expected 1 got $count", E_USER_WARNING);
        }

        return $relays[0];
    }
}
