<?php


namespace Bydedi\Shipping\Ups\Service\Locator\Params;

use DOMDocument;
use DOMElement;
use DOMNode;

/**
 * Class AbstractParam
 * @package Bydedi\Shipping\Ups\Service\Locator\Params
 */
abstract class AbstractParam implements UpsParam
{
    /**
     * @return array
     */
    abstract protected function toArray();

    /**
     * @return array
     */
    public function jsonSerialize()
    {
        return array_map(
            function ($value) {
                if (is_int($value) || is_float($value)) {
                    $value = (string) $value;
                }

                return $value;
            },
            $this->toArray()
        );
    }


    /**
     * @param DOMDocument  $document
     * @param DOMNode|null $node
     */
    public function xmlSerialize(DOMDocument $document, DOMNode $node = null)
    {
        if ($node === null) {
            $node = $document;
        }

        $toArray = $this->toArray();
        array_walk(
            $toArray,
            function ($value, $key) use ($document, $node) {
                $child = $document->createElement($key);
                if ($value instanceof UpsParam) {
                    $value->xmlSerialize($document, $child);
                } else {
                    $child->nodeValue = $value;
                }

                $node->appendChild($child);
            }
        );
    }
}
