<?php

namespace Bydedi\Shipping\Ups\Service\Locator\Params;

use DOMDocument;
use DOMNode;

/**
 * Class LocatorRequest
 */
class LocatorRequest extends AbstractParam
{

    /**
     * @var Request
     */
    protected $Request;

    /**
     * @var OriginAddress
     */
    protected $OriginAddress;

    /**
     * @var Translate
     */
    protected $Translate;

    /**
     * @var UnitOfMeasurement
     */
    protected $UnitOfMeasurement;

    /**
     * @var LocationSearchCriteria
     */
    protected $searchCriteria;


    /**
     * LocatorRequest constructor.
     *
     * @param Request                $Request
     * @param OriginAddress          $OriginAddress
     * @param Translate              $Translate
     * @param UnitOfMeasurement      $UnitOfMeasurement
     * @param LocationSearchCriteria $searchCriteria
     */
    public function __construct(
        Request $Request,
        OriginAddress $OriginAddress,
        Translate $Translate,
        UnitOfMeasurement $UnitOfMeasurement,
        LocationSearchCriteria $searchCriteria
    ) {
        $this->Request                = $Request;
        $this->OriginAddress          = $OriginAddress;
        $this->Translate              = $Translate;
        $this->UnitOfMeasurement      = $UnitOfMeasurement;
        $this->searchCriteria = $searchCriteria;
    }


    /**
     * @param  string $LocationID
     * @return LocatorRequest
     */
    public function setLocationID($LocationID)
    {
        $this->LocationID = $LocationID;
        return $this;
    }

    /**
     * {@inheritdoc}
     */
    public function xmlSerialize(DOMDocument $document, DOMNode $node = null)
    {
        if ($node === null) {
            $node = $document->createElement('LocatorRequest');
            $document->appendChild($node);
        }
        parent::xmlSerialize($document, $node);
    }

    /**
     * {@inheritdoc}
     */
    protected function toArray()
    {
        return [
            'Request'                => $this->Request,
            'OriginAddress'          => $this->OriginAddress,
            'Translate'              => $this->Translate,
            'UnitOfMeasurement'      => $this->UnitOfMeasurement,
            'LocationSearchCriteria' => $this->searchCriteria,
        ];
    }
}
