<?php

namespace Bydedi\Shipping\Ups\Service\Locator;

use Bydedi\Shipping\Ups\Service\Locator\Params\AccessPointSearch;
use Bydedi\Shipping\Ups\Service\Locator\Params\AccessRequest;
use Bydedi\Shipping\Ups\Service\Locator\Params\AddressKeyFormat;
use Bydedi\Shipping\Ups\Service\Locator\Params\TransactionReference;
use Bydedi\Shipping\Ups\Service\Locator\Params\LocationSearchCriteria;
use Bydedi\Shipping\Ups\Service\Locator\Params\LocatorRequest;
use Bydedi\Shipping\Ups\Service\Locator\Params\OriginAddress;
use Bydedi\Shipping\Ups\Service\Locator\Params\Request;
use Bydedi\Shipping\Ups\Service\Locator\Params\Translate;
use Bydedi\Shipping\Ups\Service\Locator\Params\UnitOfMeasurement;

/**
 * Class RequestFormatter
 */
class RequestFormatter
{

    protected $apiKey;

    protected $identification;

    protected $password;


    /**
     * LocatorRequestFactory constructor.
     *
     * @param $apiKey
     */
    public function __construct($apiKey, $identification, $password)
    {
        $this->apiKey         = $apiKey;
        $this->identification = $identification;
        $this->password       = $password;
    }


    /**
     * @param string     $addressLine
     * @param string     $city
     * @param string     $zipCode
     * @param string     $coutnryIsoCode2
     * @param string     $phoneNumber
     * @param $locationId $accessPointId
     * @param string     $locale
     *
     * @return LocatorRequest
     */
    public function getRequest(
        $addressLine = '',
        $city = '',
        $zipCode = '',
        $coutnryIsoCode2 = '',
        $phoneNumber = '',
        $locationId = '',
        $locale = 'fr_FR'
    ) {
        $param = new LocatorRequest(
            new Request(
                'Locator',
                '64',
                new TransactionReference('Dedi')
            ),
            new OriginAddress(
                $phoneNumber,
                new AddressKeyFormat(
                    $addressLine,
                    $city,
                    '',
                    $zipCode,
                    '',
                    $coutnryIsoCode2
                )
            ),
            new Translate($locale),
            new UnitOfMeasurement('KM'),
            new LocationSearchCriteria(
                '10',
                '15',
                null,
                new AccessPointSearch($locationId)
            )
        );

        return $param;
    }

    /**
     * @return AccessRequest
     */
    public function getAccessRequest()
    {
        return new AccessRequest($this->apiKey, $this->identification, $this->password);
    }
}
