<?php

namespace Bydedi\Shipping\Ups\Service\Locator\Xml;

use DOMDocument;
use Bydedi\Shipping\Ups\Service\Exception\Exception;
use Bydedi\Shipping\Ups\Service\Locator\Params\UpsParam;
use GuzzleHttp\ClientInterface;

/**
 * Class Client
 */
class Client
{

    /**
     * @var string
     */
    protected $env;

    /**
     * @var ClientInterface
     */
    protected $guzzle;


    /**
     * Client constructor.
     *
     * @param $env
     */
    public function __construct($env, ClientInterface $client)
    {
        $this->env    = $env;
        $this->guzzle = $client;
    }

    /**
     * @return string
     */
    protected function getEndpoint()
    {
        return $this->env === 'prod'
            ? 'https://onlinetools.ups.com/ups.app/xml/Locator'
            : 'https://wwwcie.ups.com/ups.app/xml/Locator'
        ;
    }


    /**
     * @return ClientInterface
     */
    protected function getGuzzle()
    {
        return $this->guzzle;
    }


    /**
     * @param    UpsParam[] $xml
     * @return   DOMDocument
     * @throws   Exception
     * @internal param UpsParam $upsParam
     */
    public function doRequest(UpsParam ...$xml)
    {
        $body = array_reduce(
            $xml,
            function ($body, UpsParam $upsParam) {
                $document = new DOMDocument();
                $upsParam->xmlSerialize($document);
                return "$body{$document->saveXML()}";
            }
        );

        $response = $this->getGuzzle()->request('post', $this->getEndpoint(), ['body' => $body]);
        $contents = $response->getBody()->getContents();

        $objResponse = new DOMDocument();
        $objResponse->loadXML($contents);

        $statusDescription = $objResponse->getElementsByTagName('ResponseStatusDescription')[0];
        $responseStatusCode        = $objResponse->getElementsByTagName('ResponseStatusCode')[0];
        if ($responseStatusCode->nodeValue != 1) {
            $error        = $objResponse->getElementsByTagName('Error')[0];
            $errorDescription = $objResponse->getElementsByTagName('ErrorDescription')[0]->nodeValue;
            $errorMessage = $statusDescription->nodeValue
            . " {$responseStatusCode->nodeValue} : {$errorDescription}";
            throw new Exception($error, $errorMessage);
        }

        return $objResponse;
    }
}
