<?php


namespace Bydedi\Shipping\Ups\Service\Locator\Xml;

use Bydedi\Shipping\Relay;
use DOMDocument;
use DOMNode;

/**
 * Class RelayFormatter
 */
class RelayFormatter
{
    /**
     * @param  DOMDocument $document
     * @return Relay[]
     */
    public function makeRelays(DOMDocument $document)
    {
        $dropLocations = $document->getElementsByTagName('DropLocation');
        $relays        = [];
        foreach ($dropLocations as $dropLocation) {
            $relays[] = $this->makeRelay($dropLocation);
        }

        return $relays;
    }


    /**
     * @param  DOMNode $dropLocation
     * @return Relay
     */
    protected function makeRelay(DOMNode $dropLocation)
    {
        $values = [];
        foreach ($dropLocation->childNodes as $childNode) {
            /*
             * @var DOMNode $childNode
             */
            $values[$childNode->nodeName] = $childNode;
        }

        $address = [];
        foreach ($values['AddressKeyFormat']->childNodes as $childNode) {
            /*
             * @var DOMNode $childNode
             */
            $address[$childNode->nodeName] = $childNode;
        }

        $geocode = [];
        foreach ($values['Geocode']->childNodes as $childNode) {
            /*
             * @var DOMNode $childNode
             */
            $geocode[$childNode->nodeName] = $childNode;
        }

        $distance = [];
        foreach ($values['Distance']->childNodes as $childNode) {
            /*
             * @var DOMNode $childNode
             */
            $distance[$childNode->nodeName] = $childNode;
        }

        $accessPoint = [];
        foreach ($values['AccessPointInformation']->childNodes as $childNode) {
            /*
             * @var DOMNode $childNode
             */
            $accessPoint[$childNode->nodeName] = $childNode;
        }

        $relay = new Relay(
            $accessPoint['PublicAccessPointID']->nodeValue,
            $address['ConsigneeName']->nodeValue,
            $address['AddressLine']->nodeValue,
            '',
            $address['PostcodePrimaryLow']->nodeValue,
            $address['PoliticalDivision2']->nodeValue,
            $address['CountryCode']->nodeValue,
            $geocode['Latitude']->nodeValue,
            $geocode['Longitude']->nodeValue,
            [],
            $distance['Value']->nodeValue
        );

        return $relay;
    }
}
