<?php

namespace Bydedi\Shipping\Ups\Service\Locator\Json;

use DOMDocument;
use DOMNode;
use PHPUnit_Framework_TestCase;

class ClientTest extends PHPUnit_Framework_TestCase
{
    public function testDoRequest()
    {
        if (empty($GLOBALS['UPS_KEY'])) {
            $this->markTestSkipped("Pas de clé d'api pour effectuer le test");
        }
        $client = new Client("test", new \GuzzleHttp\Client());
        $json = '{
"AccessRequest": {
"AccessLicenseNumber": "' . $GLOBALS['UPS_KEY'] . '",
"UserId": "Your UserID",
"Password": "Your Password"
},
"LocatorRequest": {
"Request": {
"RequestAction": "Locator",
"RequestOption": "1",
"TransactionReference": {
"CustomerContext": "XOLT Sample Code"
}
},
"OriginAddress": {
"PhoneNumber": "",
"AddressKeyFormat": {
"AddressLine": "61 N Ave NW",
"PoliticalDivision2": "Atlanta",
"PoliticalDivision1": "",
"PostcodePrimaryLow": "30308",
"PostcodeExtendedLow": "",
"CountryCode": "US"
}
},
"Translate": {
"Locale": "en_US"
},
"UnitOfMeasurement": {
"Code": "MI"
},
"LocationSearchCriteria": {
"SearchOption": {
"OptionType": {
"Code": "01"
},
"OptionCode": {
"Code": "002"
}
},
"MaximumListSize": "1",
"SearchRadius": "50"
}
}
}';

        $response = $client->doRequest(new UpsParamMock($json));
        $this->assertNotEmpty($response->LocatorResponse);
        $this->assertNotEmpty($response->LocatorResponse->Response);
        $this->assertEquals("Success", $response->LocatorResponse->Response->ResponseStatusDescription);
    }

}

class UpsParamMock implements \Bydedi\Shipping\Ups\Service\Locator\Params\UpsParam
{
    protected $json = "";

    /**
     * JsonParam constructor.
     *
     * @param string $json
     */
    public function __construct($json)
    {
        $this->json = $json;
    }


    /**
     * Specify data which should be serialized to JSON
     *
     * @link   http://php.net/manual/en/jsonserializable.jsonserialize.php
     * @return mixed data which can be serialized by <b>json_encode</b>,
     * which is a value of any type other than a resource.
     * @since  5.4.0
     */
    function jsonSerialize()
    {
        return json_decode($this->json);
    }

    /**
     * @return \DOMNode
     */
    public function xmlSerialize(DOMDocument $document, DOMNode $node = null)
    {
        $document->getLineNo();
        $node->getLineNo();
        return new \DOMNode();
    }
}