<?php

namespace Bydedi\Shipping\Ups\Service\Locator\Json;

use Bydedi\Shipping\Ups\Service\Locator\Params\AccessRequest;
use Bydedi\Shipping\Ups\Service\Locator\Params\LocatorRequest;
use Bydedi\Shipping\Ups\Service\Locator\Params\UpsParam;
use PHPUnit_Framework_TestCase;

class RelayFetcherTest extends PHPUnit_Framework_TestCase
{
    public function testFetch()
    {
        $json = '{
"Request": {
"RequestAction": "Locator",
"RequestOption": "1",
"TransactionReference": {
"CustomerContext": "XOLT Sample Code"
}
},
"OriginAddress": {
"PhoneNumber": "",
"AddressKeyFormat": {
"AddressLine": "61 N Ave NW",
"PoliticalDivision2": "Atlanta",
"PoliticalDivision1": "GA",
"PostcodePrimaryLow": "30308",
"PostcodeExtendedLow": "",
"CountryCode": "US"
}
},
"Translate": {
"Locale": "en_US"
},
"UnitOfMeasurement": {
"Code": "MI"
}
}';
        $accessJson = '{
"AccessLicenseNumber": "key",
"UserId": "test",
"Password": "test"
}';

        $locatorrequestMock = $this
            ->getMockBuilder(LocatorRequest::class)
            ->setMethods(['jsonSerialize'])
            ->disableOriginalConstructor()
            ->getMock();

        $locatorrequestMock
            ->expects($this->any())
            ->method('jsonSerialize')
            ->withAnyParameters()
            ->will(
                $this->returnCallback(
                    function () use ($json) {
                        return json_decode($json);
                    }
                )
            );

        $accessRequestMock = $this
            ->getMockBuilder(AccessRequest::class)
            ->setMethods(['jsonSerialize'])
            ->disableOriginalConstructor()
            ->getMock();

        $accessRequestMock
            ->expects($this->any())
            ->method('jsonSerialize')
            ->withAnyParameters()
            ->will(
                $this->returnCallback(
                    function () use ($accessJson) {
                        return json_decode($accessJson);
                    }
                )
            );

        $client = $this
            ->getMockBuilder(Client::class)
            ->setMethods(['doRequest'])
            ->disableOriginalConstructor()
            ->getMock();

        $client
            ->expects($this->any())
            ->method('doRequest')
            ->with($this->isInstanceOf(UpsParam::class))
            ->will(
                $this->returnCallback(
                    function () {
                        return json_decode(file_get_contents(__DIR__ . '/response1.json'));
                    }
                )
            )
        ;

        $relayFetcher = new RelayFetcher($client, new RelayFormatter());
        $results = $relayFetcher->fetchRelays($locatorrequestMock, $accessRequestMock);
        $this->assertCount(2, $results);
        foreach ($results as $result) {
            $this->assertEquals('ALPHARETTA', $result->getCity());
        }
    }
}