<?php


namespace Bydedi\Shipping\Ups\Service\Locator\Json;

use Bydedi\Shipping\Relay;
use PHPUnit_Framework_TestCase;

class RelayFormatterTest extends PHPUnit_Framework_TestCase
{
    /**
     * @dataProvider relayResponseProvider
     *
     * @param $json
     */
    public function testMakeRelay($json)
    {
        $factory = new RelayFormatter();
        $relays = $factory->makeRelays($json);
        $this->assertRelaysCorrects($relays);
    }

    /**
     * @param Relay[] $relays
     */
    protected function assertRelaysCorrects($relays)
    {
        $this->assertInstanceOf(Relay::class, $relays[0]);
        $this->assertEquals("U97120651", $relays[0]->getId());
        $this->assertEquals("US", $relays[0]->getCountry());
        $this->assertEquals("UPS STORE 2 - ", $relays[0]->getName());
        $this->assertEquals("319 CURIE DR", $relays[0]->getAddr1());
        $this->assertEquals("ALPHARETTA", $relays[0]->getCity());
        $this->assertEquals("1.3", $relays[0]->getDistance());
        $this->assertTrue(is_array($relays[0]->getHoraires()));
        $this->assertEquals('09:30', $relays[0]->getHoraires()['Lundi'][0]);
        $this->assertEquals('19:30', $relays[0]->getHoraires()['Lundi'][1]);
        $this->assertCount(0, $relays[0]->getHoraires()['Dimanche']);
        $this->assertEquals("34.10262680", $relays[0]->getLatitude());
        $this->assertEquals("-84.2099075", $relays[0]->getLongitude());
        $this->assertEquals("30005", $relays[0]->getZipcode());
    }

    public function relayResponseProvider()
    {
        return [
            [
                json_decode(file_get_contents(__DIR__ . '/response0.json'))
            ],
            [
                json_decode(file_get_contents(__DIR__ . '/response1.json'))
            ]
        ];
    }

}