<?php

namespace Bydedi\Shipping\Ups\Service\Locator;

use Bydedi\Shipping\Relay;
use Bydedi\Shipping\Ups\Service\Exception\Exception;
use GuzzleHttp\Client;
use PHPUnit_Framework_TestCase;
use Bydedi\Shipping\Ups\Service\Locator\Json\Client as JsonClient;
use Bydedi\Shipping\Ups\Service\Locator\Json\RelayFetcher as JsonRelayFetcher;
use Bydedi\Shipping\Ups\Service\Locator\Json\RelayFormatter as JsonRelayFormatter;
use Bydedi\Shipping\Ups\Service\Locator\Xml\Client as XmlClient;
use Bydedi\Shipping\Ups\Service\Locator\Xml\RelayFormatter as XmlRelayFormatter;
use Bydedi\Shipping\Ups\Service\Locator\Xml\RelayFetcher as XmlRelayFetcher;

/**
 * Class LocatorTest
 *
 * @package Bydedi\Shipping\Ups\Service\Locator
 */
class LocatorTest extends PHPUnit_Framework_TestCase
{
    public function fetcherProvider()
    {
        return [
            'json' => [new JsonRelayFetcher(new JsonClient("test", new Client()), new JsonRelayFormatter())],
            'xml' => [new XmlRelayFetcher(new XmlClient("test", new Client()), new XmlRelayFormatter())],
        ];
    }

    /**
     * @param RelayFetcherInterface $relayFetcher
     * @throws Exception
     *
     * @dataProvider fetcherProvider
     */
    public function testGetRelays(RelayFetcherInterface $relayFetcher)
    {
        if (empty($GLOBALS['UPS_KEY'])) {
            $this->markTestSkipped("Pas de clé d'api pour effectuer le test");
        }

        $locator = new Locator(new RequestFormatter($GLOBALS['UPS_KEY'], 'test', 'test'), $relayFetcher);

        try {
            $relays = $locator->getRelays('', 'Atlanta', '30308', 'US');
            array_walk(
                $relays, function (Relay $relay) {
                    $this->assertEquals('ATLANTA', $relay->getCity());
                }
            );
        } catch (Exception $exception) {
            var_dump($exception->getError());
            throw $exception;
        }
    }


    public function testGetRelayJson()
    {
        if (empty($GLOBALS['UPS_KEY'])) {
            $this->markTestSkipped("Pas de clé d'api pour effectuer le test");
        }

        $relayFetcher = new JsonRelayFetcher(new JsonClient("prod", new Client()), new JsonRelayFormatter());
        $locator = new Locator(new RequestFormatter($GLOBALS['UPS_KEY'], 'test', 'test'), $relayFetcher);

        try {
            $relay = $locator->getRelay("U97120651", '','FR');
            $this->assertEquals("U97120651", $relay->getId());
        } catch (Exception $exception) {
            var_dump($exception->getError());
            throw $exception;
        }
    }


}