<?php

namespace Bydedi\Shipping\Ups\Service\Locator\Xml;

use DOMDocument;
use DOMNode;
use PHPUnit_Framework_TestCase;

class ClientTest extends PHPUnit_Framework_TestCase
{
    public function testDoRequest()
    {
        if (empty($GLOBALS['UPS_KEY'])) {
            $this->markTestSkipped("Pas de clé d'api pour effectuer le test");
        }
        $client = new Client("test", new \GuzzleHttp\Client());
        $xml = '<?xml version="1.0"?>
<AccessRequest xml:lang="en-US">
<AccessLicenseNumber>' . $GLOBALS['UPS_KEY'] . '</AccessLicenseNumber>
<UserId>Your UserID</UserId>
<Password>Your Password</Password>
</AccessRequest>';
        $xml2 = '<?xml version="1.0"?>
<LocatorRequest>
<Request>
<RequestAction>Locator</RequestAction>
<RequestOption>64</RequestOption>
<TransactionReference>
<CustomerContext>XOLT Sample Code</CustomerContext>
</TransactionReference>
</Request>
<OriginAddress>
<PhoneNumber>1234567891</PhoneNumber>
<AddressKeyFormat>
<AddressLine>Street Address</AddressLine>
<PoliticalDivision2>Atlanta</PoliticalDivision2>
<PoliticalDivision1>State</PoliticalDivision1>
<PostcodePrimaryLow>12345</PostcodePrimaryLow>
<PostcodeExtendedLow>1234</PostcodeExtendedLow>
<CountryCode>US</CountryCode>
</AddressKeyFormat>
</OriginAddress>
<Translate>
<Locale>en_US</Locale>
</Translate>
<UnitOfMeasurement>
<Code>MI</Code>
</UnitOfMeasurement>
<LocationSearchCriteria>
<SearchOption>
<OptionType>
<Code>01</Code>
</OptionType>
<OptionCode>
<Code>002</Code>
</OptionCode>
</SearchOption>
<MaximumListSize>1</MaximumListSize>
<SearchRadius>50</SearchRadius>
</LocationSearchCriteria>
</LocatorRequest>';

        $response = $client->doRequest(new UpsParam($xml), new UpsParam($xml2));
        $this->assertNotEmpty($response->getElementsByTagName('LocatorResponse')[0]);
        $this->assertNotEmpty($response->getElementsByTagName('Response')[0]);
        $this->assertEquals("Success", $response->getElementsByTagName('ResponseStatusDescription')[0]->nodeValue);
    }

    public function testDoRequestWithLocationID()
    {
        if (empty($GLOBALS['UPS_KEY'])) {
            $this->markTestSkipped("Pas de clé d'api pour effectuer le test");
        }
        $client = new Client("prod", new \GuzzleHttp\Client());
        $xml = '<?xml version="1.0"?>
<AccessRequest xml:lang="en-US">
<AccessLicenseNumber>' . $GLOBALS['UPS_KEY'] . '</AccessLicenseNumber>
<UserId>Your UserID</UserId>
<Password>Your Password</Password>
</AccessRequest>';
        $xml2 = '<?xml version="1.0"?>
<LocatorRequest>
<Request>
<RequestAction>Locator</RequestAction>
<RequestOption>64</RequestOption>
<TransactionReference>
<CustomerContext>XOLT Sample Code</CustomerContext>
</TransactionReference>
</Request>
<OriginAddress>
<PhoneNumber></PhoneNumber>
<AddressKeyFormat>
<AddressLine></AddressLine>
<PoliticalDivision2>Paris</PoliticalDivision2>
<PoliticalDivision1></PoliticalDivision1>
<PostcodePrimaryLow></PostcodePrimaryLow>
<PostcodeExtendedLow></PostcodeExtendedLow>
<CountryCode>FR</CountryCode>
</AddressKeyFormat>
</OriginAddress>
<Translate>
<Locale>fr_FR</Locale>
</Translate>
<UnitOfMeasurement>
<Code>KM</Code>
</UnitOfMeasurement>
<LocationSearchCriteria>
<AccessPointSearch>
    <PublicAccessPointID>U97120651</PublicAccessPointID>
</AccessPointSearch>
<MaximumListSize>10</MaximumListSize>
<SearchRadius>15</SearchRadius>
</LocationSearchCriteria>
</LocatorRequest>';

        $response = $client->doRequest(new UpsParam($xml), new UpsParam($xml2));
        $dropLocations = $response->getElementsByTagName('DropLocation');
        $this->assertEquals(1, $dropLocations->length);
    }

}

class UpsParam implements \Bydedi\Shipping\Ups\Service\Locator\Params\UpsParam
{
    protected $xml;

    /**
     * JsonParam constructor.
     *
     * @param string $xml
     */
    public function __construct($xml)
    {
        $this->xml = $xml;
    }


    /**
     * Specify data which should be serialized to JSON
     *
     * @link   http://php.net/manual/en/jsonserializable.jsonserialize.php
     * @return mixed data which can be serialized by <b>json_encode</b>,
     * which is a value of any type other than a resource.
     * @since  5.4.0
     */
    function jsonSerialize()
    {
        return [];
    }

    public function xmlSerialize(DOMDocument $document, DOMNode $node = null)
    {
        if ($node !== null) {
            $node->getLineNo();
        }
        $document->loadXML($this->xml);
    }
}