<?php

namespace Bydedi\Shipping\Ups\Service\Locator\Xml;

use Bydedi\Shipping\Relay;
use Bydedi\Shipping\Ups\Service\Locator\Params\AccessRequest;
use Bydedi\Shipping\Ups\Service\Locator\Params\LocatorRequest;
use DOMDocument;
use PHPUnit_Framework_TestCase;

class RelayFetcherTest extends PHPUnit_Framework_TestCase
{
    public function testFetch()
    {
        $xml = '<?xml version="1.0"?>
<AccessRequest xml:lang="en-US">
<AccessLicenseNumber>test</AccessLicenseNumber>
<UserId>Your UserID</UserId>
<Password>Your Password</Password>
</AccessRequest>';
        $xml2 = '<?xml version="1.0"?>
<LocatorRequest>
<LocationID>154483</LocationID>
<Request>
<RequestAction>Locator</RequestAction>
<RequestOption>64</RequestOption>
<TransactionReference>
<CustomerContext>XOLT Sample Code</CustomerContext>
</TransactionReference>
</Request>
<OriginAddress>
<PhoneNumber></PhoneNumber>
<AddressKeyFormat>
<AddressLine></AddressLine>
<PoliticalDivision2>Atlanta</PoliticalDivision2>
<PoliticalDivision1></PoliticalDivision1>
<PostcodePrimaryLow></PostcodePrimaryLow>
<PostcodeExtendedLow></PostcodeExtendedLow>
<CountryCode>US</CountryCode>
</AddressKeyFormat>
</OriginAddress>
<Translate>
<Locale>en_US</Locale>
</Translate>
<UnitOfMeasurement>
<Code>MI</Code>
</UnitOfMeasurement>
<LocationSearchCriteria>
<SearchOption>
<OptionType>
<Code>01</Code>
</OptionType>
<OptionCode>
<Code>002</Code>
</OptionCode>
</SearchOption>
<MaximumListSize>1</MaximumListSize>
<SearchRadius>50</SearchRadius>
</LocationSearchCriteria>
</LocatorRequest>';
        $locatorrequestMock = $this->mockLocatorRequest($xml);
        $accessRequestMock = $this->mockAccessRequest($xml2);
        $client = $this->mockXmlClient($accessRequestMock, $locatorrequestMock);

        $relayFetcher = new RelayFetcher($client, new RelayFormatter());
        $results = $relayFetcher->fetchRelays($locatorrequestMock, $accessRequestMock);
        foreach ($results as $result) {
            $this->assertInstanceOf(Relay::class, $result);
        }
    }

    /**
     * @param $accessRequestMock
     * @param $locatorrequestMock
     * @param $xml2
     * @return \PHPUnit_Framework_MockObject_MockObject
     */
    protected function mockXmlClient($accessRequestMock, $locatorrequestMock)
    {
        $client = $this->getMockBuilder(Client::class)->setMethods(['doRequest'])->disableOriginalConstructor()->getMock();
        $client->expects($this->any())->method('doRequest')->with($this->equalTo($accessRequestMock), $this->equalTo($locatorrequestMock))->will($this->returnCallback(function () {
                $DOMDocument = new DOMDocument();
                $DOMDocument->load(__DIR__ . "/response.xml");
                return $DOMDocument;
            }));
        return $client;
    }

    /**
     * @param $xml2
     * @return \PHPUnit_Framework_MockObject_MockObject
     */
    protected function mockAccessRequest($xml2)
    {
        $accessRequestMock = $this->getMockBuilder(AccessRequest::class)->setMethods(['xmlSerialize'])->disableOriginalConstructor()->getMock();
        $accessRequestMock->expects($this->any())->method('xmlSerialize')->withAnyParameters()->will($this->returnCallback(function () use ($xml2) {
                $DOMDocument = new DOMDocument();
                $DOMDocument->loadXML($xml2);
                return $DOMDocument->firstChild;
            }));
        return $accessRequestMock;
    }

    /**
     * @param $xml
     * @return \PHPUnit_Framework_MockObject_MockObject
     */
    protected function mockLocatorRequest($xml)
    {
        $locatorrequestMock = $this->getMockBuilder(LocatorRequest::class)->setMethods(['xmlSerialize'])->disableOriginalConstructor()->getMock();
        $locatorrequestMock->expects($this->any())->method('xmlSerialize')->withAnyParameters()->will($this->returnCallback(function () use ($xml) {
                $DOMDocument = new DOMDocument();
                $DOMDocument->loadXML($xml);
                return $DOMDocument->firstChild;
            }));
        return $locatorrequestMock;
    }

}