<?php

namespace Bydedi\Shipping\Ups\Service\Locator\Xml;

use Bydedi\Shipping\Relay;
use PHPUnit_Framework_TestCase;

class RelayFormatterTest extends PHPUnit_Framework_TestCase
{
    /**
     * @dataProvider relayResponseProvider
     *
     * @param $document
     */
    public function testMakeRelay(\DOMDocument $document)
    {
        $factory = new RelayFormatter();
        $relays = $factory->makeRelays($document);
        $this->assertRelaysCorrects($relays);
    }

    /**
     * @param Relay[] $relays
     */
    protected function assertRelaysCorrects($relays)
    {
        $this->assertInstanceOf(Relay::class, $relays[0]);
        $this->assertEquals("U97120651", $relays[0]->getId());
        $this->assertEquals("US", $relays[0]->getCountry());
        $this->assertEquals("UPS STORE 3 - ", $relays[0]->getName());
        $this->assertEquals("320 CURIE DR", $relays[0]->getAddr1());
        $this->assertEquals("ALPHARETTA", $relays[0]->getCity());
        $this->assertEquals("1.3", $relays[0]->getDistance());
        $this->assertTrue(is_array($relays[0]->getHoraires()));// TODO
        $this->assertEquals("34.11262680", $relays[0]->getLatitude());
        $this->assertEquals("-84.2099075", $relays[0]->getLongitude());
        $this->assertEquals("30005", $relays[0]->getZipcode());
    }

    public function relayResponseProvider()
    {
        $DOMDocument = new \DOMDocument();
        $DOMDocument->load(__DIR__ . "/response.xml");
        return [
            [$DOMDocument]
        ];
    }


}