<?php

namespace Bydedi\Shipping\Ups\Service;

use Bydedi\Shipping\Relay;
use Bydedi\Shipping\Ups\Service\Exception\Exception;
use PHPUnit_Framework_TestCase;

class UpsTest extends PHPUnit_Framework_TestCase
{
    public function getListProvider()
    {
        return [
            'json' => ['json'],
            'xml' => ['xml'],
        ];
    }

    /**
     * @param $format
     * @throws Exception
     *
     * @dataProvider getListProvider
     */
    public function testGetList($format)
    {
        if (empty($GLOBALS['UPS_KEY'])) {
            $this->markTestSkipped("Pas de clé d'api pour effectuer le test");
        }
        $config = array(
            'api_key' => $GLOBALS['UPS_KEY'],
            'identification' => "test",
            'password' => "test",
            'format' => $format,
        );
        $ups = new Ups(['ups' => $config]);

        try {
            $relays = $ups->getList(['ville' => 'Atlanta', 'pays' => 'US', 'code_postal' => '30308', 'locale' => 'fr_FR']);
            array_walk(
                $relays, function (Relay $relay) {
                    $this->assertEquals('ATLANTA', $relay->getCity());
                }
            );
        } catch (Exception $exception) {
            var_dump($exception->getError());
            throw $exception;
        }
    }


    public function testGetRelay()
    {
        if (empty($GLOBALS['UPS_KEY'])) {
            $this->markTestSkipped("Pas de clé d'api pour effectuer le test");
        }

        $config = array(
            'api_key' => $GLOBALS['UPS_KEY'],
            'identification' => "test",
            'password' => "test",
            'format' => 'json',
            'env' => 'prod'
        );
        $ups = new Ups(['ups' => $config]);

        try {
            $relay = $ups->getRelay("U97120651", 'US');
            $this->assertEquals("U97120651", $relay->getId());
        } catch (Exception $exception) {
            var_dump($exception->getError());
            throw $exception;
        }
    }


}